/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;

import com.springsource.util.osgi.internal.StandardPackageAdminUtil;

/**
 * {@link OsgiBundleActivator} initialises the util.osgi bundle.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * This class is not thread safe.
 * 
 * @author Glyn Normington
 * @since Jersey
 */
public class OsgiBundleActivator implements BundleActivator {

    private StandardPackageAdminUtil standardPackageAdminUtil = null;

    private BundleContext bundleContext;

    private ServiceRegistration packageAdminUtilServiceRegistration;

    /**
     * {@inheritDoc}
     */
    public void start(BundleContext bundleContext) throws Exception {
        this.bundleContext = bundleContext;
        if (this.standardPackageAdminUtil == null) {
            this.standardPackageAdminUtil = new StandardPackageAdminUtil(bundleContext);
            this.packageAdminUtilServiceRegistration = this.bundleContext.registerService(PackageAdminUtil.class.getName(),
                this.standardPackageAdminUtil, null);
        }
    }

    /**
     * {@inheritDoc}
     */
    public void stop(BundleContext bundleContext) throws Exception {
        if (this.standardPackageAdminUtil != null) {
            this.standardPackageAdminUtil.stop();
            this.packageAdminUtilServiceRegistration.unregister();
            this.standardPackageAdminUtil = null;
        }
    }

}
