/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi;

import org.osgi.framework.Bundle;

/**
 * {@link PackageAdminUtil} provides utilities relating to {@link org.osgi.service.packageadmin.PackageAdmin PackageAdmin}.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this class must be thread safe.
 * 
 * @author Glyn Normington
 * @since Jersey
 */
public interface PackageAdminUtil {

    /**
     * Issue {@link org.osgi.service.packageadmin.PackageAdmin#refreshPackages(Bundle[]) refreshPackages} and wait for at most the given timeout for the asynchronous refresh
     * operation to complete.
     * 
     * @param bundles the {@link Bundle Bundles} whose exported packages are to be refreshed or <code>null</code> for
     *        all <code>Bundle</code>s updated or uninstalled since {@link org.osgi.service.packageadmin.PackageAdmin#refreshPackages(Bundle[]) refreshPackages} was last called
     * @param timeoutMillis a number of milliseconds to wait for the asynchronous refresh operation to complete
     */
    void refreshPackages(Bundle[] bundles, long timeoutMillis);

}
