/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest;


/**
 * Represents a bundle's <code>Bundle-SymbolicName</code> header.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * May not be thread safe.
 */
public interface BundleSymbolicName extends Parameterised {

    /**
     * An enumeration of the legal values for a bundle symbolic name's <code>fragment-attachment</code> directive.
     * <p />
     */
    public enum FragmentAttachment {
        /**
         * Fragments can attach at any time while the host is resolved or during the process of resolving.
         */
        ALWAYS,
        /**
         * Fragments may not attach to the bundle.
         */
        NEVER,
        /**
         * Fragments must only be attached while the bundle is resolving.
         */
        RESOLVE_TIME;
    }

    /**
     * Returns the header's symbolic name, or <code>null</code> if no symbolic name is specified.
     * 
     * @return the symbolic name
     */
    String getSymbolicName();

    /**
     * Sets the header's symbolic name
     * 
     * @param symbolicName the symbolic name
     */
    void setSymbolicName(String symbolicName);

    /**
     * Returns the value of the <code>singleton</code> directive. Returns the default value of <code>false</code> if no
     * <code>singleton</code> directive is specified.
     * 
     * @return the singleton directive
     */
    boolean isSingleton();

    /**
     * Sets the value of the <code>singleton</code> directive.
     * @param singleton the singleton directive's value
     */
    void setSingleton(boolean singleton);

    /**
     * Returns value of the <code>fragment-attachment</code> directive. Returns the default value of <code>ALWAYS</code>
     * if no <code>fragment-attachment</code> directive is specified.
     * 
     * @return the <code>fragment-attachment</code> directive
     */
    FragmentAttachment getFragmentAttachment();

    /**
     * Sets the value of the <code>fragment-attachment</code> directive.
     * 
     * @param fragmentAttachment the fragment-attachment directive's value
     */
    void setFragmentAttachment(FragmentAttachment fragmentAttachment);
}
