/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest;

import com.springsource.util.osgi.VersionRange;


/**
 * Represents a single entry in a bundle's <code>DynamicImport-Package</code> header.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * May not be thread safe.
 */
public interface DynamicallyImportedPackage extends Parameterised {
    
    /**
     * Returns the (possibly wildcarded) name of the package in this entry.
     * 
     * @return the package name
     */
    String getPackageName();
    
    /**
     * Sets the name of the package in this entry.
     * @param packageName the package's name.
     */
    void setPackageName(String packageName);
    
    /**
     * Returns the value of the import's <code>bundle-version</code> attribute. If no such attribute is specified
     * the default version range of [0, infinity) is returned.
     * 
     * @return The value of the <code>bundle-version</code> attribute.
     */
    VersionRange getBundleVersion();
    
    /**
     * Sets the value of the import's <code>bundle-version</code> attribute.
     * @param versionRange the value of the <code>bundle-version</code> attribute.
     */
    void setBundleVersion(VersionRange versionRange);
    
    /**
     * Returns the value of the import's <code>bundle-symbolic-name</code> attribute. If no such attribute is
     * specified <code>null</code> is returned.
     * 
     * @return The value of the import's <code>bundle-symbolic-name</code> attribute.
     */
    String getBundleSymbolicName();
     
    /**
     * Sets the value of the import's <code>bundle-symbolic-name</code> attribute.
     * 
     * @param bundleSymbolicName the value of the <code>bundle-symbolic-name</code> attribute.
     */
    void setBundleSymbolicName(String bundleSymbolicName);
    
    /**
     * Returns the version range of the import. If no <code>version</code> attribute is specified
     * the default range of [0, infinity) is returned.
     * 
     * @return the import's version range
     */
    VersionRange getVersion();
    
    /**
     * Sets the version range of the import.
     * 
     * @param versionRange the import's version range.
     */
    void setVersion(VersionRange versionRange);
}
