/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest;

import com.springsource.util.osgi.VersionRange;

public interface FragmentHost extends Parameterised {

    /**
     * Enumeration of the valid values for the header's <code>extension</code> directive
     * that applies when a fragment attaches to the system bundle.
     */    
    public enum Extension {
        /**
         * The fragment is a framework extension bundle.
         */
        FRAMEWORK, 
        /**
         * The fragment is a boot classpath extension bundle.
         */
        BOOTCLASSPATH
    };

    /**
     * Returns the bundle symbolic name specified in the header, or <code>null</code> if no <code>Fragment-Host</code> is specified.
     * 
     * @return the bundle symbolic name
     */
    String getBundleSymbolicName();

    /**
     * Set the bundle symbolic name in the header
     * 
     * @param hostName the bundle symbolic name of the fragment's host
     */
    void setBundleSymbolicName(String hostName);    

    /**
     * Returns the value of the header's <code>extension</code> directive, or <code>null</code> if no such directive is specified.
     * 
     * @return the extension directive
     */
    Extension getExtension();

    /**
     * Set the value of the header's <code>extension</code> directive.
     * @param extension the value for the extension directive
     */
    void setExtension(Extension extension);
    
    /**
     * Returns the value of the header's <code>bundle-version</code> attribute. If no such attribute is specified, returns the
     * default version range of [0, infinity).
     * 
     * @return the value of the <code>bundle-version</code> attribute.
     */
    VersionRange getBundleVersion();
    
    /**
     * Sets the value of the header's <code>bundle-version</code> directive.
     * 
     * @param versionRange the value for the <code>bundle-version</code> directive.
     */
    void setBundleVersion(VersionRange versionRange);
}
