/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest;

import java.util.List;

/**
 * Represents the <code>Import-Bundle</code> header in a {@link BundleManifest}.
 * 
 * <strong>Concurrent Semantics</strong><br />
 * May not be thread-safe.
 */
public interface ImportBundle extends Parseable {

    /**
     * Returns a <code>List</code> of the bundles that are imported. Returns an empty <code>List</code> if no bundles
     * are imported.
     * 
     * @return the imported bundles.
     */
    List<ImportedBundle> getImportedBundles();

    /**
     * Adds an import of the bundle with the supplied symbolic name to this <code>Import-Bundle</code> header.
     * 
     * @param bundleSymbolicName The name of the imported bundle
     * @return the newly-created <code>ImportBundle</code>.
     */
    ImportedBundle addImportedBundle(String bundleSymbolicName);
}
