/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest;

import java.util.List;

/**
 * Represents the <code>Import-Library</code> header in a {@link BundleManifest}.
 * 
 * <strong>Concurrent Semantics</strong><br />
 * May not be thread-safe.
 */
public interface ImportLibrary extends Parseable {
    
    /**
     * Returns a <code>List</code> of the libraries that are imported. Returns an empty <code>List</code> if no libraries
     * are imported.
     * 
     * @return the imported libraries.
     */
    List<ImportedLibrary> getImportedLibraries();

    /**
     * Adds an import of the library with the supplied symbolic name to this <code>Import-Library</code> header.
     * 
     * @param librarySymbolicName The name of the imported library.
     * @return the newly-created <code>ImportedLibrary</code>.
     */
    ImportedLibrary addImportedLibrary(String librarySymbolicName);
}
