/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest;

import com.springsource.util.osgi.VersionRange;

/**
 * A common interface for the entries in the three import headers: <code>Import-Package</code>, <code>Import-Bundle</code>, and
 * <code>Import-Library</code>.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * May not be thread-safe.
 * 
 * @see ImportedPackage
 * @see ImportedBundle
 * @see ImportedLibrary
 */
public interface Imported extends Parameterised {
    
    /**
     * Returns the version range of the import. If no <code>version</code> attribute is specified
     * the default range of [0, infinity) is returned.
     * 
     * @return the import's version range
     */
    VersionRange getVersion();
    
    /**
     * Sets the version range of the import.
     * 
     * @param versionRange the import's version range.
     */
    void setVersion(VersionRange versionRange);

    /**
     * Returns the value of the import's <code>resolution</code> directive. If no such directive is specified the
     * default value of {@link Resolution#MANDATORY} is returned.
     * 
     * @return the value of the import's resolution directive.
     */
    Resolution getResolution();
    
    /**
     * Sets the value of the import's <code>resolution</code> directive.
     * 
     * @param resolution The import's resolution directive
     */
    void setResolution(Resolution resolution);
}
