/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest;

/**
 * Represents a single entry in a bundle's <code>Import-Bundle</code> header.
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 * May not be thread-safe.
 * 
 * @since Jersey
 */
public interface ImportedBundle extends Imported {

    /**
     * Returns the symbolic name of the bundle that is imported, never <code>null</code>.
     * 
     * @return the imported bundle's symbolic name.
     */
    String getBundleSymbolicName();
    
    /**
     * Sets the symbolic name of the bundle that is imported
     * @param bundleSymbolicName the imported bundle's symbolic name
     * @throws IllegalArgumentException if the supplied bundleSymbolicName is <code>null</code>
     */
    void setBundleSymbolicName(String bundleSymbolicName) throws IllegalArgumentException;

    /**
     * Returns the value of the import's <code>sharing</code> directive. If no such directive is specified the
     * default value of {@link Sharing#AUTOMATIC} is returned.
     * 
     * @return the value of the import's sharing directive.
     */
    Sharing getSharing();
    
    /**
     * Sets the value of the import's <code>sharing</code> directive.
     * 
     * @param sharing the value of the import's sharing directive
     */
    void setSharing(Sharing sharing);

    /**
     * Returns <code>true</code> if the import's <code>import-scope</code> directive is present and has 
     * a value of <code>application</code>, otherwise <code>false</code> is returned.
     * 
     * @return <code>true</code> if and only if the import-scope directive has a value of application
     */
    boolean isApplicationImportScope();
    
    /**
     * Sets the <code>import-scope</code> directive
     * 
     * @param applicationImportScope Whether or not the import's scope is application
     */
    void setApplicationImportScope(boolean applicationImportScope);
}
