/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest;

/**
 * Represents a single entry in a bundle's <code>Import-Library</code> header.
 * <p />
 *
 * <strong>Concurrent Semantics</strong><br />
 * May not be thread-safe.
 * 
 * @since Jersey
 */
public interface ImportedLibrary extends Imported {

    /**
     * Returns the symbolic name of the library that is imported, never <code>null</code>.
     * 
     * @return the imported library's symbolic name.
     */
    String getLibrarySymbolicName();
    
    /**
     * Sets the symbolic name of the library that is imported.
     * 
     * @param librarySymbolicName The imported library's symbolic name
     * @throws IllegalArgumentException if librarySymbolicName is <code>null</code>
     */
    void setLibrarySymbolicName(String librarySymbolicName) throws IllegalArgumentException;
    
    /**
     * Returns the value of the import's <code>sharing</code> directive. If no such directive is specified the
     * default value of {@link Sharing#AUTOMATIC} is returned.
     * 
     * @return the value of the import's sharing directive.
     */
    Sharing getSharing();
    
    /**
     * Sets the value of the import's <code>sharing</code> directive.
     * 
     * @param sharing the value of the import's sharing directive
     */
    void setSharing(Sharing sharing);
}
