/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest;

import java.util.Map;

/**
 * Represents a header or header entry that can be parameterised, i.e. it has attributes and directives.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * May not be thread-safe.
 */
public interface Parameterised extends Parseable {

    /**
     * Returns a <code>Map</code> of the header or header entry's attributes
     * 
     * @return the attributes
     */
    Map<String, String> getAttributes();

    /**
     * Returns a <code>Map</code> of the header or header entry's directives
     * 
     * @return the directives
     */
    Map<String, String> getDirectives();
}
