/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest;

/**
 * Represents a header or header entry that can be converted into a parseable string and that can have its values
 * (re)set by parsing a string.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * May not be thread-safe.
 * 
 */
public interface Parseable {

    /**
     * Converts the header or header entry into a parseable <code>String</code>.
     * 
     * @return The header in the form of a parseable String
     */
    String toParseString();

    /**
     * Resets that header's values by parsing the supplied <code>String</code>.
     * 
     * @param string The String to be parsed
     */
    void resetFromParseString(String string);
}
