/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest;

import java.util.List;

/**
 * Represents the <code>Require-Bundle</code> header in a {@link BundleManifest}.
 * 
 * <strong>Concurrent Semantics</strong><br />
 * May not be thread-safe.
 * 
 */
public interface RequireBundle extends Parseable {

    /**
     * Returns a <code>List</code> of the bundles that are required. Returns an empty <code>List</code> if no bundles
     * are required.
     * 
     * @return the required bundles
     */
    List<RequiredBundle> getRequiredBundles();

    /**
     * Adds a required bundle with the supplied bundle symbolic name to this <code>Require-Bundle</code> header.
     * <p/>
     * If there is already a required bundle with the given symbolic name, a duplicate is added and the resultant
     * manifest will not conform to the OSGi specification. This behaviour may change: see issue DMS-548.
     * 
     * @param requiredBundle the symbolic name of the required bundle
     * @return the newly-created <code>RequiredBundle</code>.
     */
    RequiredBundle addRequiredBundle(String requiredBundle);
}
