/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.internal;

import org.osgi.framework.Constants;

import com.springsource.util.osgi.VersionRange;
import com.springsource.util.osgi.manifest.Imported;
import com.springsource.util.osgi.manifest.Resolution;
import com.springsource.util.osgi.manifest.parse.HeaderParser;

/**
 * <strong>Concurrent Semantics</strong><br />
 * Not thread-safe.
 */
abstract class BaseImported extends BaseCompoundHeaderEntry implements Imported {

    BaseImported(HeaderParser parser, String name) {
        super(parser, name);
    }

    /**
     * {@inheritDoc}
     */
    public Resolution getResolution() {
        String value = getDirectives().get(Constants.RESOLUTION_DIRECTIVE);
        if (Constants.RESOLUTION_OPTIONAL.equals(value)) {
            return Resolution.OPTIONAL;
        } else {
            return Resolution.MANDATORY;
        }
    }

    /**
     * {@inheritDoc}
     */
    public VersionRange getVersion() {
        String value = getAttributes().get(Constants.VERSION_ATTRIBUTE);
        return new VersionRange(value);
    }

    /**
     * {@inheritDoc}
     */
    public void setResolution(Resolution resolution) {
        if (resolution == null) {
            getDirectives().remove(Constants.RESOLUTION_DIRECTIVE);
            return;
        }

        switch (resolution) {
            case OPTIONAL:
                getDirectives().put(Constants.RESOLUTION_DIRECTIVE, Constants.RESOLUTION_OPTIONAL);
                break;
            default:
                getDirectives().remove(Constants.RESOLUTION_DIRECTIVE);
        }
    }

    /**
     * {@inheritDoc}
     */
    public void setVersion(VersionRange versionRange) {
        if (versionRange != null) {
            getAttributes().put(Constants.VERSION_ATTRIBUTE, versionRange.toParseString());
        } else {
            getAttributes().remove(Constants.VERSION_ATTRIBUTE);
        }
    }
}
