/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.internal;

import java.util.List;

import org.osgi.framework.Constants;

import com.springsource.util.osgi.manifest.BundleActivationPolicy;
import com.springsource.util.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.util.osgi.manifest.parse.HeaderParser;

class StandardBundleActivationPolicy extends BaseParameterised implements BundleActivationPolicy {

    StandardBundleActivationPolicy(HeaderParser parser) {
        super(parser);
    }

    @Override
    HeaderDeclaration parse(HeaderParser parser, String parseString) {
        return parser.parseBundleActivationPolicy(parseString);
    }

    /** 
     * {@inheritDoc}
     */
    public Policy getActivationPolicy() {        
        if (Constants.ACTIVATION_LAZY.equals(this.name)) {
            return Policy.LAZY;
        } else {
            return Policy.EAGER;
        }        
    }

    /** 
     * {@inheritDoc}
     */
    public void setActivationPolicy(Policy policy) {
        if (Policy.LAZY.equals(policy)) {
            this.name = Constants.ACTIVATION_LAZY;
        } else {
            this.name = null;
        }
    }

    /** 
     * {@inheritDoc}
     */
    public List<String> getExclude() {
        return HeaderUtils.toList(Constants.EXCLUDE_DIRECTIVE, getDirectives());
    }

    /** 
     * {@inheritDoc}
     */
    public List<String> getInclude() {
        return HeaderUtils.toList(Constants.INCLUDE_DIRECTIVE, getDirectives());
    }
}
