/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.internal;

import org.osgi.framework.Constants;

import com.springsource.util.osgi.manifest.BundleSymbolicName;
import com.springsource.util.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.util.osgi.manifest.parse.HeaderParser;


/**
 * <strong>Concurrent Semantics</strong><br />
 * Not thread-safe.
 */
class StandardBundleSymbolicName  extends BaseParameterised implements BundleSymbolicName {

    StandardBundleSymbolicName(HeaderParser parser) {
        super(parser);
    }

    @Override
    HeaderDeclaration parse(HeaderParser parser, String parseString) {
        return parser.parseBundleSymbolicName(parseString);
    }

    /** 
     * {@inheritDoc}
     */
    public FragmentAttachment getFragmentAttachment() {        
        String value = this.getDirectives().get(Constants.FRAGMENT_ATTACHMENT_DIRECTIVE);
        if (Constants.FRAGMENT_ATTACHMENT_NEVER.equals(value)) {
            return FragmentAttachment.NEVER;
        } else if (Constants.FRAGMENT_ATTACHMENT_RESOLVETIME.equals(value)) {
            return FragmentAttachment.RESOLVE_TIME;
        } else {
            return FragmentAttachment.ALWAYS;
        }
    }

    /** 
     * {@inheritDoc}
     */
    public String getSymbolicName() {
        return this.name;
    }

    /** 
     * {@inheritDoc}
     */
    public boolean isSingleton() {
        return Boolean.valueOf(this.getDirectives().get(Constants.SINGLETON_DIRECTIVE));
    }

    /** 
     * {@inheritDoc}
     */
    public void setFragmentAttachment(FragmentAttachment fragmentAttachment) {
        switch (fragmentAttachment) {
            case NEVER:
                this.getDirectives().put(Constants.FRAGMENT_ATTACHMENT_DIRECTIVE, Constants.FRAGMENT_ATTACHMENT_NEVER);
                break;
            case RESOLVE_TIME:
                this.getDirectives().put(Constants.FRAGMENT_ATTACHMENT_DIRECTIVE, Constants.FRAGMENT_ATTACHMENT_RESOLVETIME);
                break;
            default:
                this.getDirectives().remove(Constants.FRAGMENT_ATTACHMENT_DIRECTIVE);
        }        
    }

    /** 
     * {@inheritDoc}
     */
    public void setSingleton(boolean singleton) {
        this.getDirectives().put(Constants.SINGLETON_DIRECTIVE, Boolean.toString(singleton));         
    }

    /** 
     * {@inheritDoc}
     */
    public void setSymbolicName(String symbolicName) {
        this.name = symbolicName;
    }
}
