/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.internal;

import java.util.List;

import org.osgi.framework.Constants;

import com.springsource.util.osgi.VersionRange;
import com.springsource.util.osgi.manifest.DynamicallyImportedPackage;
import com.springsource.util.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.util.osgi.manifest.parse.HeaderParser;


/**
 * <strong>Concurrent Semantics</strong><br />
 * Not thread-safe.
 */
class StandardDynamicallyImportedPackage extends BaseCompoundHeaderEntry implements DynamicallyImportedPackage {
    
    StandardDynamicallyImportedPackage(HeaderParser parser, String name) {
        super(parser, name);
    }

    @Override
    HeaderDeclaration parse(HeaderParser parser, String parseString) {
        List<HeaderDeclaration> headerDeclarations = parser.parseDynamicImportPackageHeader(parseString);
        return headerDeclarations.get(0);
    }

    /** 
     * {@inheritDoc}
     */
    public String getPackageName() {
        return this.name;
    }

    /** 
     * {@inheritDoc}
     */
    public void setPackageName(String packageName) {
        this.name = packageName;
    }
    
    /** 
     * {@inheritDoc}
     */
    public String getBundleSymbolicName() {
        return getAttributes().get(Constants.BUNDLE_SYMBOLICNAME_ATTRIBUTE);
    }

    /** 
     * {@inheritDoc}
     */
    public VersionRange getBundleVersion() {
        return new VersionRange(getAttributes().get(Constants.BUNDLE_VERSION_ATTRIBUTE));
    }

    /** 
     * {@inheritDoc}
     */
    public VersionRange getVersion() {
        String value = getAttributes().get(Constants.VERSION_ATTRIBUTE);
        return new VersionRange(value);        
    }

    /** 
     * {@inheritDoc}
     */
    public void setVersion(VersionRange versionRange) {
        if (versionRange != null) {
            getAttributes().put(Constants.VERSION_ATTRIBUTE, versionRange.toParseString());
        } else {
            getAttributes().remove(Constants.VERSION_ATTRIBUTE);
        }
    }

    /** 
     * {@inheritDoc}
     */
    public void setBundleSymbolicName(String bundleSymbolicName) {
        getAttributes().put(Constants.BUNDLE_SYMBOLICNAME_ATTRIBUTE, bundleSymbolicName);        
    }

    /** 
     * {@inheritDoc}
     */
    public void setBundleVersion(VersionRange versionRange) {
        if (versionRange != null) {
            getAttributes().put(Constants.BUNDLE_VERSION_ATTRIBUTE, versionRange.toParseString());
        } else {
            getAttributes().remove(Constants.BUNDLE_VERSION_ATTRIBUTE);
        }
        
    }
}
