/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.internal;

import java.util.List;

import org.osgi.framework.Constants;

import com.springsource.util.osgi.manifest.ExportPackage;
import com.springsource.util.osgi.manifest.ExportedPackage;
import com.springsource.util.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.util.osgi.manifest.parse.HeaderParser;


/**
 * <strong>Concurrent Semantics</strong><br />
 * Not thread-safe.
 */
class StandardExportPackage extends CompoundParseable<ExportedPackage> implements ExportPackage {

    StandardExportPackage(HeaderParser parser) {
        super(parser);
    }

    /** 
     * {@inheritDoc}
     */
    @Override
    List<HeaderDeclaration> parse(String parseString) {
        return this.parser.parsePackageHeader(parseString, Constants.EXPORT_PACKAGE);        
    }

    /** 
     * {@inheritDoc}
     */
    public ExportedPackage addExportedPackage(String exportedPackage) {
        return add(exportedPackage);        
    }

    /** 
     * {@inheritDoc}
     */
    public List<ExportedPackage> getExportedPackages() {
        return this.components;        
    }

    /** 
     * {@inheritDoc}
     */
    @Override
    ExportedPackage newEntry(String name) {
        return new StandardExportedPackage(this.parser, name);
    }
}
