/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.internal;

import java.util.List;

import org.osgi.framework.Constants;
import org.osgi.framework.Version;

import com.springsource.util.osgi.manifest.ExportedPackage;
import com.springsource.util.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.util.osgi.manifest.parse.HeaderParser;

/**
 * <strong>Concurrent Semantics</strong><br />
 * Not thread-safe.
 */
public class StandardExportedPackage extends BaseCompoundHeaderEntry implements ExportedPackage {    
    
    StandardExportedPackage(HeaderParser parser, String name) {
        super(parser, name);
    }
    
    @Override
    HeaderDeclaration parse(HeaderParser parser, String parseString) {
        List<HeaderDeclaration> header = parser.parsePackageHeader(parseString, Constants.EXPORT_PACKAGE);
        return header.get(0);
    }

    /** 
     * {@inheritDoc}
     */
    public List<String> getExclude() {
        return HeaderUtils.toList(Constants.EXCLUDE_DIRECTIVE, getDirectives()); 
    }

    /** 
     * {@inheritDoc}
     */
    public List<String> getInclude() {
        return HeaderUtils.toList(Constants.INCLUDE_DIRECTIVE, getDirectives());        
    }

    /** 
     * {@inheritDoc}
     */
    public List<String> getMandatory() {
        return HeaderUtils.toList(Constants.MANDATORY_DIRECTIVE, getDirectives());
    }

    /** 
     * {@inheritDoc}
     */
    public String getPackageName() {
        return this.name;
    }

    /** 
     * {@inheritDoc}
     */
    public List<String> getUses() {
        return HeaderUtils.toList(Constants.USES_DIRECTIVE, getDirectives());
    }

    /** 
     * {@inheritDoc}
     */
    public Version getVersion() {
        String value = getAttributes().get(Constants.VERSION_ATTRIBUTE);
        if (value != null) {
            return new Version(value);
        } else {
            return Version.emptyVersion;
        }
    }

    /** 
     * {@inheritDoc}
     */
    public void setVersion(Version version) {
        if (version != null) {
            getAttributes().put(Constants.VERSION_ATTRIBUTE, version.toString());
        } else {
            getAttributes().remove(Constants.VERSION_ATTRIBUTE);
        }
    }

    /** 
     * {@inheritDoc}
     */
    public void setPackageName(String packageName) {
        if (packageName == null) {
            throw new IllegalArgumentException("packageName must not be null");
        }
        this.name = packageName;        
    }
}
