/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.internal;

import org.osgi.framework.Constants;

import com.springsource.util.osgi.VersionRange;
import com.springsource.util.osgi.manifest.FragmentHost;
import com.springsource.util.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.util.osgi.manifest.parse.HeaderParser;


/**
 * <strong>Concurrent Semantics</strong><br />
 * Not thread-safe.
 */
class StandardFragmentHost extends BaseParameterised implements FragmentHost {

    StandardFragmentHost(HeaderParser parser) {
        super(parser);
    }

    /** 
     * {@inheritDoc}
     */
    @Override
    HeaderDeclaration parse(HeaderParser parser, String parseString) {        
        return parser.parseFragmentHostHeader(parseString);
    }

    /** 
     * {@inheritDoc}
     */
    public String getBundleSymbolicName() {
        return this.name;
    }

    /** 
     * {@inheritDoc}
     */
    public Extension getExtension() {
        String value = getDirectives().get(Constants.EXTENSION_DIRECTIVE);
        if (Constants.EXTENSION_BOOTCLASSPATH.equals(value)) {
            return Extension.BOOTCLASSPATH;
        } else if (Constants.EXTENSION_FRAMEWORK.equals(value)) {
            return Extension.FRAMEWORK;
        }
        return null;
    }

    /** 
     * {@inheritDoc}
     */
    public void setBundleSymbolicName(String hostName) {
        this.name = hostName;        
    }

    /** 
     * {@inheritDoc}
     */
    public void setExtension(Extension extension) {
        if (extension == null) {
            getDirectives().remove(Constants.EXTENSION_DIRECTIVE);
            return;
        }
        
        switch (extension) {
            case BOOTCLASSPATH:
                getDirectives().put(Constants.EXTENSION_DIRECTIVE, Constants.EXTENSION_BOOTCLASSPATH);
                break;
            case FRAMEWORK:
                getDirectives().put(Constants.EXTENSION_DIRECTIVE, Constants.EXTENSION_FRAMEWORK);
                break;            
        }
    }

    /** 
     * {@inheritDoc}
     */
    public VersionRange getBundleVersion() {
        return new VersionRange(getAttributes().get(Constants.BUNDLE_VERSION_ATTRIBUTE));        
    }

    /** 
     * {@inheritDoc}
     */
    public void setBundleVersion(VersionRange versionRange) {
        if (versionRange == null) {
            getAttributes().remove(Constants.BUNDLE_VERSION_ATTRIBUTE);
            
        } else {
            getAttributes().put(Constants.BUNDLE_VERSION_ATTRIBUTE, versionRange.toParseString());
        }        
    }
}
