/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.internal;

import java.util.List;

import com.springsource.util.osgi.manifest.ImportLibrary;
import com.springsource.util.osgi.manifest.ImportedLibrary;
import com.springsource.util.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.util.osgi.manifest.parse.HeaderParser;


/**
 * <strong>Concurrent Semantics</strong><br />
 * Not thread-safe
 */
public class StandardImportLibrary extends CompoundParseable<ImportedLibrary> implements ImportLibrary {

    StandardImportLibrary(HeaderParser parser) {
        super(parser);        
    }

    /** 
     * {@inheritDoc}
     */
    @Override
    List<HeaderDeclaration> parse(String parseString) {
        return this.parser.parseImportLibraryHeader(parseString);        
    }

    /** 
     * {@inheritDoc}
     */
    public ImportedLibrary addImportedLibrary(String importedLibrary) {
        return add(importedLibrary);
    }

    /** 
     * {@inheritDoc}
     */
    public List<ImportedLibrary> getImportedLibraries() {
        return this.components;
    }

    /** 
     * {@inheritDoc}
     */
    @Override
    ImportedLibrary newEntry(String name) {
        return new StandardImportedLibrary(this.parser, name);
    }
}
