/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.internal;

import com.springsource.util.osgi.manifest.ImportedLibrary;
import com.springsource.util.osgi.manifest.Sharing;
import com.springsource.util.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.util.osgi.manifest.parse.HeaderParser;


/**
 * <strong>Concurrent Semantics</strong><br />
 * Not thread-safe.
 * 
 */
public class StandardImportedLibrary extends BaseImported implements ImportedLibrary {
    
    private static final String SHARING_SHARE = "share";
    
    private static final String SHARING_CLONE = "clone";
    
    private static final String SHARING_DIRECTIVE = "sharing";

    StandardImportedLibrary(HeaderParser parser, String name) {
        super(parser, name);
    }

    /** 
     * {@inheritDoc}
     */
    @Override
    HeaderDeclaration parse(HeaderParser parser, String parseString) {
        return parser.parseImportLibraryHeader(parseString).get(0);
    }

    /** 
     * {@inheritDoc}
     */
    public String getLibrarySymbolicName() {
        return this.name;
    }

    /** 
     * {@inheritDoc}
     */
    public void setLibrarySymbolicName(String librarySymbolicName) {
        if (librarySymbolicName == null) {
            throw new IllegalArgumentException("librarySymbolicName must not be null");
        }
        this.name = librarySymbolicName;
    }

    /** 
     * {@inheritDoc}
     */
    public Sharing getSharing() {
        String value = getDirectives().get(SHARING_DIRECTIVE);
        if (SHARING_SHARE.equals(value)) {
            return Sharing.SHARE;
        } else if (SHARING_CLONE.equals(value)) {
            return Sharing.CLONE;
        } else {
            return Sharing.AUTOMATIC;
        }
    }

    /** 
     * {@inheritDoc}
     */
    public void setSharing(Sharing sharing) {
        if (sharing == null) {
            getDirectives().remove(SHARING_DIRECTIVE);
            return;
        }
        
        switch (sharing) {
            case CLONE: 
                getDirectives().put(SHARING_DIRECTIVE, SHARING_CLONE);
                break;
            case SHARE:
                getDirectives().put(SHARING_DIRECTIVE, SHARING_SHARE);
                break;
            default:
                getDirectives().remove(SHARING_DIRECTIVE);
                break;       
        }   
    }
}
