/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.internal;

import java.util.List;

import com.springsource.util.osgi.manifest.RequireBundle;
import com.springsource.util.osgi.manifest.RequiredBundle;
import com.springsource.util.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.util.osgi.manifest.parse.HeaderParser;


/**
 * <strong>Concurrent Semantics</strong><br />
 * Not thread-safe.
 */
public class StandardRequireBundle extends CompoundParseable<RequiredBundle> implements RequireBundle {

    StandardRequireBundle(HeaderParser parser) {
        super(parser);
    }

    /** 
     * {@inheritDoc}
     */
    public RequiredBundle addRequiredBundle(String requiredBundle) {
        return add(requiredBundle);
    }

    /** 
     * {@inheritDoc}
     */
    public List<RequiredBundle> getRequiredBundles() {
        return this.components;
    }

    /** 
     * {@inheritDoc}
     */
    @Override
    List<HeaderDeclaration> parse(String parseString) {
        return this.parser.parseRequireBundleHeader(parseString);        
    }

    /** 
     * {@inheritDoc}
     */
    @Override
    RequiredBundle newEntry(String name) {
        return new StandardRequiredBundle(this.parser, name);
    }

}
