/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.internal;

import org.osgi.framework.Constants;

import com.springsource.util.osgi.VersionRange;
import com.springsource.util.osgi.manifest.RequiredBundle;
import com.springsource.util.osgi.manifest.Resolution;
import com.springsource.util.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.util.osgi.manifest.parse.HeaderParser;

/**
 * <strong>Concurrent Semantics</strong><br />
 * Not thread-safe.
 */
public class StandardRequiredBundle extends BaseCompoundHeaderEntry implements RequiredBundle {

    StandardRequiredBundle(HeaderParser parser, String name) {
        super(parser, name);
    }

    public String getBundleSymbolicName() {
        return this.name;
    }

    /**
     * {@inheritDoc}
     */
    public Resolution getResolution() {
        String value = getDirectives().get(Constants.RESOLUTION_DIRECTIVE);
        if (Constants.RESOLUTION_OPTIONAL.equals(value)) {
            return Resolution.OPTIONAL;
        } else {
            return Resolution.MANDATORY;
        }
    }

    /**
     * {@inheritDoc}
     */
    public Visibility getVisibility() {
        String value = getDirectives().get(Constants.VISIBILITY_DIRECTIVE);
        if (Constants.VISIBILITY_REEXPORT.equals(value)) {
            return Visibility.REEXPORT;
        } else {
            return Visibility.PRIVATE;
        }
    }

    /**
     * {@inheritDoc}
     */
    public void setBundleSymbolicName(String bundleSymbolicName) {
        if (bundleSymbolicName == null) {
            throw new IllegalArgumentException("bundleSymbolicName must not be null");
        }
        this.name = bundleSymbolicName;
    }

    /**
     * {@inheritDoc}
     */
    public void setResolution(Resolution resolution) {
        if (resolution == null) {
            getDirectives().remove(Constants.RESOLUTION_DIRECTIVE);
        } else {
            switch (resolution) {
                case OPTIONAL:
                    getDirectives().put(Constants.RESOLUTION_DIRECTIVE, Constants.RESOLUTION_OPTIONAL);
                    break;
                default:
                    getDirectives().remove(Constants.RESOLUTION_DIRECTIVE);
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    public void setVisibility(Visibility visibility) {
        if (visibility == null) {
            getDirectives().remove(Constants.VISIBILITY_DIRECTIVE);
        } else {
            switch (visibility) {
                case REEXPORT:
                    getDirectives().put(Constants.VISIBILITY_DIRECTIVE, Constants.VISIBILITY_REEXPORT);
                    break;
                default:
                    getDirectives().remove(Constants.VISIBILITY_DIRECTIVE);
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    HeaderDeclaration parse(HeaderParser parser, String parseString) {
        return parser.parseRequireBundleHeader(parseString).get(0);
    }
    
    /** 
     * {@inheritDoc}
     */
    public VersionRange getBundleVersion() {
        return new VersionRange(getAttributes().get(Constants.BUNDLE_VERSION_ATTRIBUTE));        
    }

    /** 
     * {@inheritDoc}
     */
    public void setBundleVersion(VersionRange versionRange) {
        if (versionRange == null) {
            getAttributes().remove(Constants.BUNDLE_VERSION_ATTRIBUTE);
            
        } else {
            getAttributes().put(Constants.BUNDLE_VERSION_ATTRIBUTE, versionRange.toParseString());
        }        
    }
}
