/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.parse;

import java.util.List;
import java.util.Map;

/**
 * Describes a header declaration (Import-Package, Export-Package, Require-Bundle, etc.) in an OSGi manifest header.
 * <p/>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * Implementations need not be thread-safe.
 * 
 * @author Rob Harrop
 * @author Glyn Normington
 * @since 1.0
 */
public interface HeaderDeclaration {

    /**
     * Returns a <code>List</code> of the names of the entries in the declaration. If the declaration has no names,
     * an empty <code>Map</code> must be returned, rather than <code>null</code>. 
     * 
     * @return the names, never <code>null</code>.
     */
    List<String> getNames();

    /**
     * Returns a <code>Map</code> of the attributes included in this declaration. If the declaration has
     * no attributes, an empty <code>Map</code> must be returned, rather than <code>null</code>.
     * 
     * @return the attributes.
     */
    Map<String, String> getAttributes();

    /**
     * Returns a <code>Map</code> of the directives included in this declaration. If the declaration has
     * no directives, an empty <code>Map</code> must be returned, rather than <code>null</code>.
     * 
     * @return the directives.
     */
    Map<String, String> getDirectives();
}
