/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.parse;

import com.springsource.util.osgi.manifest.parse.standard.StandardHeaderParser;

/**
 * Factory for creating {@link HeaderParser} instances
 * <p/>
 * .
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Rob Harrop
 * @author Andy Clement
 * @since 1.0
 */
public final class HeaderParserFactory {

	/**
	 * Creates a new {@link HeaderParser} that logs to the supplied {@link ParserLogger}.
	 * 
	 * @param logger the <code>ParserLogger</code> to log to.
	 * @return the new <code>HeaderParser</code>.
	 */
	public static HeaderParser newHeaderParser(ParserLogger logger) {
		return new StandardHeaderParser(logger);
	}
}
