/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.parse;

/**
 * <p>
 * This is a stand-in logging service just for parsing manifests. It can run before the normal serviceability services
 * have come up and allow errors to be correctly reported from the start of the server bootstrap process.
 * </p>
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Implementations of this interface should be Thread Safe
 * 
 * @author Christopher Frost
 * @author Ben Hale
 * @since 1.0
 */
public interface ParserLogger {

    /**
     * Deal with a exception at level 'Error' logging it with what ever services are available.
     * 
     * @param re
     * @param item
     */
    void outputErrorMsg(Exception re, String item);

    /**
     * Reports if this logging service has been used or not. If it has been used the parsing activities that have taken
     * place since this logger was created or reset have encountered problems of some kind.
     * 
     * @return String array of all log event messages since the parser was created or cleaned
     */
    String[] errorReports();

}
