/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.osgi.manifest.parse.standard;

import java.io.PrintStream;
import java.util.Collections;
import java.util.List;

import com.springsource.util.osgi.manifest.parse.HeaderDeclaration;

/**
 * Simple debug visitor that can be plugged into the parser to observe the
 * visiting order. Plugging it in is as easy as using the StandardHeaderParser
 * constructor that takes a visitor:
 * <code>new StandardHeaderParser(new DebugVisitor())</code>. By default the
 * logged output will go to System.out - but a difference PrintStream can be
 * specified through the DebugVisitor constructor.
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe.
 * 
 * @author Andy Clement
 */
public class DebugVisitor implements HeaderVisitor {

	private PrintStream printStream;

	public DebugVisitor() {
		printStream = System.out;
	}

	public DebugVisitor(PrintStream ps) {
		this.printStream = ps;
	}

	public void visitAttribute(String name, String value) {
		printStream.println("visitAttribute(" + name + "=" + value + ")");
	}

	public void visitDirective(String name, String value) {
		printStream.println("visitDirective(" + name + ":=" + value + ")");
	}

	public void visitSymbolicName(String symbolicName) {
		printStream.println("visitSymbolicName(" + symbolicName + ")");
	}

	public void visitUniqueName(String uniqueName) {
		printStream.println("visitUniqueName(" + uniqueName + ")");
	}

	public void visitWildcardName(String name) {
		printStream.println("visitWildcardName(" + name + ")");
	}

	public void endvisit() {
		printStream.println("endVisit()");
	}

	public void clauseEnded() {
		printStream.println("clauseEnded()");
	}

	public List<HeaderDeclaration> getHeaderDeclarations() {
		printStream.println("getHeaderDeclarations()");
		return Collections.emptyList();
	}

	public HeaderDeclaration getFirstHeaderDeclaration() {
		printStream.println("getFirstHeaderDeclaration()");
		return null;
	}
	
	public void initialize() {
		
	}
}
